API docs for “spamfighter.api.message.firewall”

# Module s.a.m.firewall

Part of spamfighter.api.message View Source

Команды `sf.message.firewall.*`.

Class | FirewallCommand | Базовая команда работы с firewall
Class | FirewallRulesGetCommand | Реализация команды `sf.message.firewall.rules.get`.
Class | FirewallRulesSetCommand | Реализация команды `sf.message.firewall.rules.set`.
Class | FirewallRulesCheckCommand | Реализация команды `sf.message.firewall.rules.check`.